class Consts:
    @property
    def value(self) -> str: ...

    CHAR: str
    WHITESPACE: str
    NOT_WHITESPACE: str
    WS: str
    NOT_WS: str
    WORD: str
    NOT_WORD: str
    DIGIT: str
    NOT_DIGIT: str
    LETTER: str
    NOT_LETTER: str
    TAB: str
    NEWLINE: str
    NOT_NEWLINE: str
    CARRIAGE_RETURN: str
    N: str
    NOT_N: str
    R: str
